==> web2ldap-0.16.15.tar.gz: web2ldap-0.16.15/etc/web2ldap/web2ldapcnf/hosts.py <==
"""
web2ldapcnf/hosts.py - Host-related options
(c) by Michael Stroeder <michael@stroeder.com>
"""

# Leave this alone
import os,web2ldapcnf

class Web2LDAPConfig:
  """
  Base class for a web2ldap host-/backend configuration section.
  
  Leave untouched!!!
  """
  def __init__(self,**kwargs):
    self.__dict__.update(kwargs)
  def get(self,name,default=None):
    self.__dict__.get(name,default)


########################################################################
# List of all LDAP hosts to use. These hosts will appear in the
# default select list of the login form.
# A list containing only one host results in a normal input field
# with the host set as default.
########################################################################

ldap_uri_list = [
  'ldap://localhost',
  (
    'ldap://localhost:1390',
    u'Local OpenLDAP 2.x server'
  ),
  (
    'ldapi://%2Ftmp%2Fopenldap-socket',
    u'Local OpenLDAP 2.x server (Unix domain socket)'
  ),
  ('ldap://ldap.openldap.org',u"OpenLDAP's Test Site"),
  ('ldap://www.nldap.com',u"Novell's Test Site"),
  ('ldap://ldap.rediris.es/c=ES','C=ES at RedIRIS'),
  ('ldap://ldap.uninett.no/dc=uninett,dc=no','UNINETT'),
  ('ldap://www.trustcenter.de/dc=trustcenter,dc=de',u'TC Trustcenter'),
  ('ldap://pks-ldap.telesec.de/c=DE','T-TeleSec PKS'),
  ('ldap://x500.bund.de/o=Bund,c=DE??one',u'X.500 Directory Informationsverbund Berlin-Bonn'),
  ('ldap://db.debian.org/dc=debian,dc=org??one',u'debian.org Developers LDAP Search'),
  ('ldap://directory.verisign.com',u"Verisign"),
  ('ldap://ldap.nrca-ds.de/dc=ldap,dc=nrca-ds,dc=de??one',u"Qualified certificates of german RegTP"),
  'ldap://ldap.itd.umich.edu',
  'ldap://ldap.baylor.edu',
  'ldap://directory.uga.edu',
  'ldap://memberdir.netscape.com',
  'ldap://x500.umn.edu',
]

########################################################################
# LDAP host(s) with their defaults can be pre-defined as dictionary
# ldap_def = {'host:port':{paramdictionary}}
########################################################################


ldap_def = {

  # Overall default values.
  # There's most times no need to adjust the values in this section
  # since they can be overridden by host specific sections (see below).
  '_': Web2LDAPConfig(

    # Search filter template for smart login
    # Use indexed attributes here!
    binddnsearch=r'(|(cn=%s)(uid=%s))',
    # Example for M$ Active Directory
#    binddnsearch=r'(|(sAMAccountName=%s)(userPrincipalName=%s))',

    # Timeout for LDAP operations (seconds)
    timeout=110,

    # Use StartTLS on connect. It's recommended saying 0 as default
    # since not many servers can handle an unknown extended control properly
    starttls=0,

    # Maximum amount of time in seconds a result is valid in the cache
    cache_timeout=900,
    # Maximum cache size in bytes (per session!)
    cache_maxmem=0,
    # regular expression of subject DNs in client certs
    ssl_valid_dn=r'/.*',
    # regular expression of subject DNs in issuer certs
    ssl_valid_idn=r'/.*',
    sec_reqlevel=0,
    # Attributes explicitly requested while doing read
    # and modify operations
#    requested_attrs=[
#      # password policy attributes
#      'passwordExpirationTime','passwordExpWarned',
#      'passwordRetryCount','retryCountResetTime','accountUnlockTime',
#      'passwordHistory','passwordAllowChangeTime',
#      # Account specifics
#      'nsAccountLock','nsLookthroughLimit',
#      # ACL attributes
#      'aci',
#      # counters
#      'numSubordinates','subordinateCount',
#    ],
    # vCard template files
    vcard_template={
      # 'object class':'pathname of vCard template file'
      'person':os.path.join(web2ldapcnf.templates_dir,'vcard_person.txt'),
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'vcard_person.txt'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'vcard_organization.txt'),
    },
    # HTML template files for printing table entries
    print_template={
      # 'object class':'pathname of printable HTML template file'
      'person':os.path.join(web2ldapcnf.templates_dir,'print_person.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'print_organization.html'),
      'organizationalUnit':os.path.join(web2ldapcnf.templates_dir,'print_organizationalUnit.html'),
    },
    # HTML template file for Basic Search form
    searchform_template= os.path.join(web2ldapcnf.templates_dir,'searchform_Base.html'),
    # HTML template file for Login form
    login_template= os.path.join(web2ldapcnf.templates_dir,'login.html'),
    # Default mechanism for BindRequest (empty string for simple bind)
    login_default_mech='',
    # Attributes which should be present in attribute select list of advanced search form
    search_attrs=['cn','mail','sn','givenName','o','ou','telephoneNumber','homePhone','l','streetAddress','uid','uidNumber','description'],
    # There are some situations where this client just wants to get the
    # attributes of an entry and not the data itself for saving bandwidth.
    # However some LDAP hosts (e.g. Notes Domino 4.61) have problems with
    # such an attribute-only request, they won't return any matches for a search.
    # If you experience these problems (no matching entry) set this to 0.
    search_attrsonly=1,
    search_tablistattrs=['cn','mail','homephone','telephonenumber','mobile'],
    # HTML template strings used to display entries in the table
    # of search results
    search_tdtemplate= {
#      'inetOrgPerson':r'%(cn)s &lt;%(mail)s&gt; Tel.: %(telephoneNumber)s or %(homePhoneNumber)s',
      'organization':r'&quot;%(o)s&quot; Tel.: %(telephoneNumber)s',
      'organizationalUnit':r'Org. Unit &quot;%(ou)s&quot; Tel.: %(telephoneNumber)s',
      'rfc822MailGroup':r'Mailing list %(cn)s &lt;%(mail)s&gt;, see %(labeledurl)s',
      'account':r'Account <strong>%(uid)s</strong>',
    },
    # Default for number of results shown per page
    search_resultsperpage=10,
    # HTML template file used for displaying entries of specific object class
    read_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organizationalPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'read_organization.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
    },
    # HTML template file used for displaying input forms for entries
    # of specific object class
    input_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_inetOrgPerson.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'inputform_posixAccount.html'),
      'msPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_msPerson.html'),
    },
    # HTML template file used for displaying operational attributes
    # in a footer when displaying a single entry
    read_operationalattrstemplate=os.path.join(web2ldapcnf.templates_dir,'read_operationalattrs.html'),
    # Number of columns for print output
    print_cols=4,
    # Dictionary { description : LDIF file name } for displaying
    # link for quickly choosing LDIF templates for new entries
    addform_entry_templates={
      'Person':os.path.join(web2ldapcnf.templates_dir,'add_person.ldif'),
      'Company':os.path.join(web2ldapcnf.templates_dir,'add_company.ldif'),
      'User':os.path.join(web2ldapcnf.templates_dir,'add_user.ldif'),
      'Org. Unit':os.path.join(web2ldapcnf.templates_dir,'add_orgunit.ldif'),
      'Group':os.path.join(web2ldapcnf.templates_dir,'add_group.ldif'),
    },
    # LDIF file used as locally stored pseudo LDAPv3 schema
    schema_uri='file:'+os.path.join(web2ldapcnf.etc_dir,os.path.join('web2ldap','localschema.ldif')),
    # The definitions for group entry administration
    groupadm_defs={
      'groupOfNames':       ('member',None),
      'groupOfUniqueNames': ('uniqueMember',None),
      'organizationalRole': ('roleOccupant',None),
      'rfc822MailGroup':    ('mail','mail'),
      'nisMailAlias':       ('rfc822MailMember','mail'),
      'mailGroup':          ('mgrprfc822mailmember','mail'),
      # Found on IBM SecureWay Directory
      'accessGroup':        ('member',None),
      # RFC2370
      'posixGroup':         ('memberUid','uid'),
      # Samba 3.0
      'sambaGroupMapping':  ('sambaSID','sambaSID'),
      # Active Directory
      'group':              ('member',None),
    },
#    link_css='/css/aho/school_2.css',
    link_css='/css/web2ldap/default.css',
  ),

  'ldap://localhost': Web2LDAPConfig(
    description=u'My poorly configured LDAP host',
  ),

  # This meant as an more complex example section
  # Adjust the settings to reflect your local LDAP installation
  'ldapi://%2Ftmp%2Fopenldap-socket/dc=stroeder,dc=de': Web2LDAPConfig(
    description=u'My Address Book',
    ssl_valid_dn=r'^/S=Stroeder/G=Michael/CN=Michael Stroeder/Email=michael@stroeder.com$',
    ssl_valid_idn=r'^/C=ZA/ST=Western Cape/L=Durbanville/O=Thawte/OU=Certificate Services/CN=Personal Freemail RSA 1999\.9\.16$',
    read_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'read_organization.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
      'bankArrangement':os.path.join(web2ldapcnf.templates_dir,'read_bankArrangement.html'),
      'musician':os.path.join(web2ldapcnf.templates_dir,'read_musician.html'),
    },
    addform_entry_templates={
      'stroeder.com Person':os.path.join(web2ldapcnf.templates_dir,'add_msperson.ldif'),
      'Company':os.path.join(web2ldapcnf.templates_dir,'add_company.ldif'),
      'User':os.path.join(web2ldapcnf.templates_dir,'add_user.ldif'),
      'Org. Unit':os.path.join(web2ldapcnf.templates_dir,'add_orgunit.ldif'),
      'Group':os.path.join(web2ldapcnf.templates_dir,'add_group.ldif'),
    },
#    login_default_mech='EXTERNAL',
    passwd_hashtypes=['ssha',''],
#    schema_uri='ldapi://%2Ftmp%2Fopenldap-socket/cn=Subschema',
  ),

  # Special example for IBM Directory Server 5.1
  # - HTML templates for searchform, read and print are used.
  # - Search table contains most significant attributes.
  # (FYI: This site is not accessible anymore.)
  'ldap://localhost:7389': Web2LDAPConfig(
    requested_attrs=[
      'ibm-audit','ibm-auditAdd','ibm-auditBind','ibm-auditDelete','ibm-auditExtOpEvent','ibm-auditFailedOpOnly','ibm-auditLog','ibm-auditModify','ibm-auditModifyDN','ibm-auditSearch','ibm-auditUnbind'
    ],
  ),

  # Example for OpenLDAP's back-config under cn=config
  'ldap://localhost/cn=config': Web2LDAPConfig(
    description=u"OpenLDAP's back-config",
    searchform_template= os.path.join(web2ldapcnf.templates_dir,'searchform_back-config.html'),
    input_template={
      'olcIncludeFile':os.path.join(web2ldapcnf.templates_dir,'inputform_olcIncludeFile.html'),
      'olcBdbConfig':os.path.join(web2ldapcnf.templates_dir,'inputform_olcBdbConfig.html'),
    },
    addform_entry_templates={
      'Include file':os.path.join(web2ldapcnf.templates_dir,'add_olcIncludeFile.ldif'),
      'Adress book (back-bdb)':os.path.join(web2ldapcnf.templates_dir,'add_olcBdbConfig_AddressBook.ldif'),
      'Unix Users (back-hdb)':os.path.join(web2ldapcnf.templates_dir,'add_olcHdbConfig_UnixUsers.ldif'),
      'back-ldap':os.path.join(web2ldapcnf.templates_dir,'add_olcIncludeFile.ldif'),
      'Schema config':os.path.join(web2ldapcnf.templates_dir,'add_olcSchemaConfig.ldif'),
    },
  ),

}

# Use the same configuration for various LDAP URLs
ldap_def['ldapi://%2Ftmp%2Fopenldap-socket/cn=config'] = ldap_def['ldap://localhost/cn=config']
ldap_def['ldap://localhost:1390/cn=config'] = ldap_def['ldap://localhost/cn=config']

==> web2ldap-0.16.23.tar.gz: web2ldap-0.16.23/etc/web2ldap/web2ldapcnf/hosts.py <==
"""
web2ldapcnf/hosts.py - Host-related options
(c) by Michael Stroeder <michael@stroeder.com>
"""

# Leave this alone
import os,web2ldapcnf

class Web2LDAPConfig:
  """
  Base class for a web2ldap host-/backend configuration section.
  
  Leave untouched!!!
  """
  def __init__(self,**kwargs):
    self.__dict__.update(kwargs)
  def get(self,name,default=None):
    self.__dict__.get(name,default)


########################################################################
# List of all LDAP hosts to use. These hosts will appear in the
# default select list of the login form.
# A list containing only one host results in a normal input field
# with the host set as default.
########################################################################

ldap_uri_list = [
  'ldap://localhost',
  (
    'ldap://localhost:1390',
    u'Local OpenLDAP 2.x server'
  ),
  (
    'ldapi://%2Ftmp%2Fopenldap-socket',
    u'Local OpenLDAP 2.x server (Unix domain socket)'
  ),
  ('ldap://ldap.openldap.org',u"OpenLDAP's Test Site"),
  ('ldap://ldap.rediris.es/c=ES','C=ES at RedIRIS'),
  ('ldap://ldap.uninett.no/dc=uninett,dc=no','UNINETT'),
  ('ldap://www.trustcenter.de/dc=trustcenter,dc=de',u'TC Trustcenter'),
  ('ldap://mailcert.t-online.de/ou%3D4901%2Cou%3Dmailcert%2Cou%3Dservices%2Cdc%3DT-Online%2Cdc%3Dcom',u'T-Online Mail Certs'),
  ('ldap://pks-ldap.telesec.de/c=DE','T-TeleSec PKS'),
  ('ldap://x500.bund.de/o=Bund,c=DE??one',u'X.500 Directory Informationsverbund Berlin-Bonn'),
  ('ldap://db.debian.org/dc=debian,dc=org??one',u'debian.org Developers LDAP Search'),
  ('ldap://directory.verisign.com',u"Verisign"),
  ('ldap://ldap.nrca-ds.de/dc=ldap,dc=nrca-ds,dc=de??one',u"Qualified certificates of german RegTP"),
  'ldap://ldap.itd.umich.edu',
  'ldap://ldap.baylor.edu',
  'ldap://directory.uga.edu',
]

########################################################################
# LDAP host(s) with their defaults can be pre-defined as dictionary
# ldap_def = {'host:port':{paramdictionary}}
########################################################################


ldap_def = {

  # Overall default values.
  # There's most times no need to adjust the values in this section
  # since they can be overridden by host specific sections (see below).
  '_': Web2LDAPConfig(

    # Search filter template for smart login
    # Use indexed attributes here!
    binddnsearch=r'(|(cn=%s)(uid=%s))',
    # Example for M$ Active Directory
#    binddnsearch=r'(|(sAMAccountName=%s)(userPrincipalName=%s))',

    # Timeout for LDAP operations (seconds)
    timeout=300,

    # Use StartTLS on connect. It's recommended saying 0 as default
    # since not many servers can handle an unknown extended control properly
    starttls=0,

    # Maximum amount of time in seconds a result is valid in the cache
    cache_timeout=900,
    # Maximum cache size in bytes (per session!)
    cache_maxmem=0,
    # regular expression of subject DNs in client certs
    ssl_valid_dn=r'/.*',
    # regular expression of subject DNs in issuer certs
    ssl_valid_idn=r'/.*',
    sec_reqlevel=0,
    # Attributes explicitly requested while doing read
    # and modify operations
    requested_attrs=[
      # password policy attributes
      'passwordExpirationTime','passwordExpWarned',
      'passwordRetryCount','retryCountResetTime','accountUnlockTime',
      'passwordHistory','passwordAllowChangeTime',
      # Account specifics
     'nsAccountLock','nsLookthroughLimit',
      # ACL attributes
      'aci','aclentry',
      # counters
      'hasSubordinates','numSubordinates','subordinateCount',
      # Proxy Authz attributes
      'authzTo','authzFrom',
    ],
    # vCard template files
    vcard_template={
      # 'object class':'pathname of vCard template file'
      'person':os.path.join(web2ldapcnf.templates_dir,'vcard_person.txt'),
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'vcard_person.txt'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'vcard_organization.txt'),
    },
    # HTML template files for printing table entries
    print_template={
      # 'object class':'pathname of printable HTML template file'
      'person':os.path.join(web2ldapcnf.templates_dir,'print_person.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'print_organization.html'),
      'organizationalUnit':os.path.join(web2ldapcnf.templates_dir,'print_organizationalUnit.html'),
    },
    # HTML template file for Basic Search form
    searchform_template= os.path.join(web2ldapcnf.templates_dir,'searchform_Base.html'),
    # HTML template file for Login form
    login_template= os.path.join(web2ldapcnf.templates_dir,'login.html'),
    # Default mechanism for BindRequest (empty string for simple bind)
    login_default_mech='',
    # Attributes which should be present in attribute select list of advanced search form
    search_attrs=['cn','mail','sn','givenName','o','ou','telephoneNumber','homePhone','l','streetAddress','uid','uidNumber','description'],
    # There are some situations where this client just wants to get the
    # attributes of an entry and not the data itself for saving bandwidth.
    # However some LDAP hosts (e.g. Notes Domino 4.61) have problems with
    # such an attribute-only request, they won't return any matches for a search.
    # If you experience these problems (no matching entry) set this to 0.
    search_attrsonly=1,
    search_tablistattrs=['cn','mail','homephone','telephonenumber','mobile'],
    # HTML template strings used to display entries in the table
    # of search results
    search_tdtemplate= {
#      'inetOrgPerson':r'%(cn)s &lt;%(mail)s&gt; Tel.: %(telephoneNumber)s or %(homePhoneNumber)s',
      'organization':r'&quot;%(o)s&quot; Tel.: %(telephoneNumber)s',
      'organizationalUnit':r'Org. Unit &quot;%(ou)s&quot; Tel.: %(telephoneNumber)s',
      'rfc822MailGroup':r'Mailing list %(cn)s &lt;%(mail)s&gt;, see %(labeledurl)s',
      'account':r'Account <strong>%(uid)s</strong>',
    },
    # Default for number of results shown per page
    search_resultsperpage=10,
    # HTML template file used for displaying entries of specific object class
    read_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organizationalPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'read_organization.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
    },
    # HTML template file used for displaying input forms for entries
    # of specific object class
    input_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_inetOrgPerson.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'inputform_posixAccount.html'),
      'msPerson':os.path.join(web2ldapcnf.templates_dir,'inputform_msPerson.html'),
    },
    # HTML template file used for displaying operational attributes
    # in a footer when displaying a single entry
    read_operationalattrstemplate=os.path.join(web2ldapcnf.templates_dir,'read_operationalattrs.html'),
    # Number of columns for print output
    print_cols=4,
    # Dictionary { description : LDIF file name } for displaying
    # link for quickly choosing LDIF templates for new entries
    addform_entry_templates={
      'Person':os.path.join(web2ldapcnf.templates_dir,'add_person.ldif'),
      'Company':os.path.join(web2ldapcnf.templates_dir,'add_company.ldif'),
      'User':os.path.join(web2ldapcnf.templates_dir,'add_user.ldif'),
      'Org. Unit':os.path.join(web2ldapcnf.templates_dir,'add_orgunit.ldif'),
      'Group':os.path.join(web2ldapcnf.templates_dir,'add_group.ldif'),
    },
    # LDIF file used as locally stored pseudo LDAPv3 schema
    schema_uri='file:'+os.path.join(web2ldapcnf.etc_dir,os.path.join('web2ldap','localschema.ldif')),
    # The definitions for group entry administration
    groupadm_defs={
      'groupOfNames':       ('member',None),
      'groupOfUniqueNames': ('uniqueMember',None),
      'organizationalRole': ('roleOccupant',None),
      'rfc822MailGroup':    ('mail','mail'),
      'nisMailAlias':       ('rfc822MailMember','mail'),
      'mailGroup':          ('mgrprfc822mailmember','mail'),
      # Found on IBM SecureWay Directory
      'accessGroup':        ('member',None),
      # RFC2370
      'posixGroup':         ('memberUid','uid'),
      # Samba 3.0
      'sambaGroupMapping':  ('sambaSID','sambaSID'),
      # Active Directory
      'group':              ('member',None),
      # draft-findlay-ldap-groupofentries
      'groupOfEntries':     ('member',None),
    },
    link_css="""
    <link rel="stylesheet" media="screen" href="/css/web2ldap/default.css">
    <link rel="stylesheet" media="print, embossed" href="/css/web2ldap/print.css">
    """,
  ),

  'ldap://localhost': Web2LDAPConfig(
    description=u'My poorly configured LDAP host',
  ),


  'ldap:///dc=stroeder,dc=de': Web2LDAPConfig(
#    schema_uri='file:'+os.path.join(web2ldapcnf.etc_dir,os.path.join('web2ldap','localschema.ldif')),
  ),

  # This meant as an more complex example section
  # Adjust the settings to reflect your local LDAP installation
  'ldapi://%2Ftmp%2Fopenldap-socket/dc=stroeder,dc=de': Web2LDAPConfig(
    description=u'My Address Book',
    ssl_valid_dn=r'^/S=Stroeder/G=Michael/CN=Michael Stroeder/Email=michael@stroeder.com$',
    ssl_valid_idn=r'^/C=ZA/ST=Western Cape/L=Durbanville/O=Thawte/OU=Certificate Services/CN=Personal Freemail RSA 1999\.9\.16$',
    read_template={
      # 'object class':'pathname of HTML template file'
      'inetOrgPerson':os.path.join(web2ldapcnf.templates_dir,'read_inetOrgPerson.html'),
      'organization':os.path.join(web2ldapcnf.templates_dir,'read_organization.html'),
      'posixAccount':os.path.join(web2ldapcnf.templates_dir,'read_posixAccount.html'),
      'bankArrangement':os.path.join(web2ldapcnf.templates_dir,'read_bankArrangement.html'),
      'musician':os.path.join(web2ldapcnf.templates_dir,'read_musician.html'),
    },
    addform_entry_templates={
      'stroeder.com Person':os.path.join(web2ldapcnf.templates_dir,'add_msperson.ldif'),
      'Company':os.path.join(web2ldapcnf.templates_dir,'add_company.ldif'),
      'User':os.path.join(web2ldapcnf.templates_dir,'add_user.ldif'),
      'Org. Unit':os.path.join(web2ldapcnf.templates_dir,'add_orgunit.ldif'),
      'Group':os.path.join(web2ldapcnf.templates_dir,'add_group.ldif'),
    },
#    login_default_mech='EXTERNAL',
    passwd_hashtypes=['ssha',''],
#    schema_uri='ldapi://%2Ftmp%2Fopenldap-socket/cn=Subschema',
#    schema_uri='file:'+os.path.join(web2ldapcnf.etc_dir,os.path.join('web2ldap','localschema.ldif')),
  ),

  # Special example for IBM Directory Server 5.1
  # - HTML templates for searchform, read and print are used.
  # - Search table contains most significant attributes.
  # (FYI: This site is not accessible anymore.)
  'ldap://localhost:7389': Web2LDAPConfig(
    requested_attrs=[
      'ibm-audit','ibm-auditAdd','ibm-auditBind','ibm-auditDelete','ibm-auditExtOpEvent','ibm-auditFailedOpOnly','ibm-auditLog','ibm-auditModify','ibm-auditModifyDN','ibm-auditSearch','ibm-auditUnbind'
    ],
  ),

  # Example for OpenLDAP's back-config under cn=config
  'ldap:///cn=config': Web2LDAPConfig(
    description=u"OpenLDAP's back-config",
#    searchform_template= os.path.join(web2ldapcnf.templates_dir,'searchform_back-config.html'),
    input_template={
      'olcIncludeFile':os.path.join(web2ldapcnf.templates_dir,'inputform_olcIncludeFile.html'),
      'olcBdbConfig':os.path.join(web2ldapcnf.templates_dir,'inputform_olcBdbConfig.html'),
      'olcHdbConfig':os.path.join(web2ldapcnf.templates_dir,'inputform_olcHdbConfig.html'),
    },
    addform_entry_templates={
      'Adress book (back-bdb)':os.path.join(web2ldapcnf.templates_dir,'add_olcBdbConfig_AddressBook.ldif'),
      'Unix Users (back-hdb)':os.path.join(web2ldapcnf.templates_dir,'add_olcHdbConfig_UnixUsers.ldif'),
#      'back-ldap':os.path.join(web2ldapcnf.templates_dir,'add_olcIncludeFile.ldif'),
      'Schema config':os.path.join(web2ldapcnf.templates_dir,'add_olcSchemaConfig.ldif'),
    },
  ),

}

# Use the same configuration for various LDAP URLs
ldap_def['ldapi://%2Ftmp%2Fopenldap-socket/cn=config'] = ldap_def['ldap:///cn=config']
